@@ -18,32 +18,37 @@
  */
 
 import _ from 'lodash';
+// required for `ngSanitize` angular module
+import 'angular-sanitize';
 
 import { i18n } from '@kbn/i18n';
 
+import routes from 'ui/routes';
 import { capabilities } from 'ui/capabilities';
 import { docTitle } from 'ui/doc_title';
 import { fatalError, toastNotifications } from 'ui/notify';
-import { timezoneProvider } from 'ui/vis/lib/timezone';
 import { timefilter } from 'ui/timefilter';
 import { npStart } from 'ui/new_platform';
 import { getSavedSheetBreadcrumbs, getCreateBreadcrumbs } from './breadcrumbs';
+import { getTimezone } from '../../../../plugins/vis_type_timelion/public';
 
 import 'uiExports/savedObjectTypes';
 
+require('ui/i18n');
 require('ui/autoload/all');
 
 // TODO: remove ui imports completely (move to plugins)
 import 'ui/directives/input_focus';
 import './directives/saved_object_finder';
 import 'ui/directives/listen';
-import 'ui/kbn_top_nav';
-import 'ui/saved_objects/ui/saved_object_save_as_checkbox';
-import '../../data/public/legacy';
+import './directives/saved_object_save_as_checkbox';
 import './services/saved_sheet_register';
 
 import rootTemplate from 'plugins/timelion/index.html';
-import { createSavedVisLoader } from '../../kibana/public/visualize';
+import { uiModules } from 'ui/modules';
+
+import { loadKbnTopNavDirectives } from '../../../../plugins/kibana_legacy/public';
+loadKbnTopNavDirectives(npStart.plugins.navigation.ui);
 
 require('plugins/timelion/directives/cells/cells');
 require('plugins/timelion/directives/fixed_element');
@@ -57,18 +62,16 @@ require('plugins/timelion/directives/timelion_options_sheet');
 
 document.title = 'Timelion - Kibana';
 
-const app = require('ui/modules').get('apps/timelion', []);
+const app = uiModules.get('apps/timelion', ['i18n', 'ngSanitize']);
 
-require('./vis');
+routes.enable();
 
-require('ui/routes').enable();
-
-require('ui/routes').when('/:id?', {
+routes.when('/:id?', {
   template: rootTemplate,
   reloadOnSearch: false,
   k7Breadcrumbs: ($injector, $route) =>
     $injector.invoke($route.current.params.id ? getSavedSheetBreadcrumbs : getCreateBreadcrumbs),
-  badge: uiCapabilities => {
+  badge: (uiCapabilities) => {
     if (uiCapabilities.timelion.save) {
       return undefined;
     }
@@ -84,10 +87,10 @@ require('ui/routes').when('/:id?', {
     };
   },
   resolve: {
-    savedSheet: function(redirectWhenMissing, savedSheets, $route) {
+    savedSheet: function (redirectWhenMissing, savedSheets, $route) {
       return savedSheets
         .get($route.current.params.id)
-        .then(savedSheet => {
+        .then((savedSheet) => {
           if ($route.current.params.id) {
             npStart.core.chrome.recentlyAccessed.add(
               savedSheet.getFullPath(),
@@ -108,7 +111,7 @@ require('ui/routes').when('/:id?', {
 
 const location = 'Timelion';
 
-app.controller('timelion', function(
+app.controller('timelion', function (
   $http,
   $route,
   $routeParams,
@@ -116,32 +119,25 @@ app.controller('timelion', function(
   $timeout,
   AppState,
   config,
-  confirmModal,
-  kbnUrl,
-  Private
+  kbnUrl
 ) {
   // Keeping this at app scope allows us to keep the current page when the user
   // switches to say, the timepicker.
   $scope.page = config.get('timelion:showTutorial', true) ? 1 : 0;
-  $scope.setPage = page => ($scope.page = page);
+  $scope.setPage = (page) => ($scope.page = page);
 
   timefilter.enableAutoRefreshSelector();
   timefilter.enableTimeRangeSelector();
 
-  const savedVisualizations = createSavedVisLoader({
-    savedObjectsClient: npStart.core.savedObjects.client,
-    indexPatterns: npStart.plugins.data.indexPatterns,
-    chrome: npStart.core.chrome,
-    overlays: npStart.core.overlays,
-  });
-  const timezone = Private(timezoneProvider)();
+  const savedVisualizations = npStart.plugins.visualizations.savedVisualizationsLoader;
+  const timezone = getTimezone(config);
 
   const defaultExpression = '.es(*)';
   const savedSheet = $route.current.locals.savedSheet;
 
   $scope.topNavMenu = getTopNavMenu();
 
-  $timeout(function() {
+  $timeout(function () {
     if (config.get('timelion:showTutorial', true)) {
       $scope.toggleMenu('showHelp');
     }
@@ -168,7 +164,7 @@ app.controller('timelion', function(
       description: i18n.translate('timelion.topNavMenu.newSheetButtonAriaLabel', {
         defaultMessage: 'New Sheet',
       }),
-      run: function() {
+      run: function () {
         kbnUrl.change('/');
       },
       testId: 'timelionNewButton',
@@ -182,7 +178,7 @@ app.controller('timelion', function(
       description: i18n.translate('timelion.topNavMenu.addChartButtonAriaLabel', {
         defaultMessage: 'Add a chart',
       }),
-      run: function() {
+      run: function () {
         $scope.$evalAsync(() => $scope.newCell());
       },
       testId: 'timelionAddChartButton',
@@ -210,10 +206,10 @@ app.controller('timelion', function(
       description: i18n.translate('timelion.topNavMenu.deleteSheetButtonAriaLabel', {
         defaultMessage: 'Delete current sheet',
       }),
-      disableButton: function() {
+      disableButton: function () {
         return !savedSheet.id;
       },
-      run: function() {
+      run: function () {
         const title = savedSheet.title;
         function doDelete() {
           savedSheet
@@ -227,11 +223,10 @@ app.controller('timelion', function(
               );
               kbnUrl.change('/');
             })
-            .catch(error => fatalError(error, location));
+            .catch((error) => fatalError(error, location));
         }
 
         const confirmModalOptions = {
-          onConfirm: doDelete,
           confirmButtonText: i18n.translate('timelion.topNavMenu.delete.modal.confirmButtonLabel', {
             defaultMessage: 'Delete',
           }),
@@ -242,12 +237,18 @@ app.controller('timelion', function(
         };
 
         $scope.$evalAsync(() => {
-          confirmModal(
-            i18n.translate('timelion.topNavMenu.delete.modal.warningText', {
-              defaultMessage: `You can't recover deleted sheets.`,
-            }),
-            confirmModalOptions
-          );
+          npStart.core.overlays
+            .openConfirm(
+              i18n.translate('timelion.topNavMenu.delete.modal.warningText', {
+                defaultMessage: `You can't recover deleted sheets.`,
+              }),
+              confirmModalOptions
+            )
+            .then((isConfirmed) => {
+              if (isConfirmed) {
+                doDelete();
+              }
+            });
         });
       },
       testId: 'timelionDeleteButton',
@@ -310,12 +311,12 @@ app.controller('timelion', function(
   }
 
   let refresher;
-  const setRefreshData = function() {
+  const setRefreshData = function () {
     if (refresher) $timeout.cancel(refresher);
     const interval = timefilter.getRefreshInterval();
     if (interval.value > 0 && !interval.pause) {
       function startRefresh() {
-        refresher = $timeout(function() {
+        refresher = $timeout(function () {
           if (!$scope.running) $scope.search();
           startRefresh();
         }, interval.value);
@@ -324,7 +325,7 @@ app.controller('timelion', function(
     }
   };
 
-  const init = function() {
+  const init = function () {
     $scope.running = false;
     $scope.search();
     setRefreshData();
@@ -343,7 +344,7 @@ app.controller('timelion', function(
       savedSheet: savedSheet,
       state: $scope.state,
       search: $scope.search,
-      dontShowHelp: function() {
+      dontShowHelp: function () {
         config.set('timelion:showTutorial', false);
         $scope.setPage(0);
         $scope.closeMenus();
@@ -357,27 +358,27 @@ app.controller('timelion', function(
       showOptions: false,
     };
 
-    $scope.toggleMenu = menuName => {
+    $scope.toggleMenu = (menuName) => {
       const curState = $scope.menus[menuName];
       $scope.closeMenus();
       $scope.menus[menuName] = !curState;
     };
 
     $scope.closeMenus = () => {
-      _.forOwn($scope.menus, function(value, key) {
+      _.forOwn($scope.menus, function (value, key) {
         $scope.menus[key] = false;
       });
     };
   };
 
-  $scope.onTimeUpdate = function({ dateRange }) {
+  $scope.onTimeUpdate = function ({ dateRange }) {
     $scope.model.timeRange = {
       ...dateRange,
     };
     timefilter.setTime(dateRange);
   };
 
-  $scope.onRefreshChange = function({ isPaused, refreshInterval }) {
+  $scope.onRefreshChange = function ({ isPaused, refreshInterval }) {
     $scope.model.refreshInterval = {
       pause: isPaused,
       value: refreshInterval,
@@ -391,33 +392,33 @@ app.controller('timelion', function(
   };
 
   $scope.$watch(
-    function() {
+    function () {
       return savedSheet.lastSavedTitle;
     },
-    function(newTitle) {
+    function (newTitle) {
       docTitle.change(savedSheet.id ? newTitle : undefined);
     }
   );
 
-  $scope.toggle = function(property) {
+  $scope.toggle = function (property) {
     $scope[property] = !$scope[property];
   };
 
-  $scope.newSheet = function() {
+  $scope.newSheet = function () {
     kbnUrl.change('/', {});
   };
 
-  $scope.newCell = function() {
+  $scope.newCell = function () {
     $scope.state.sheet.push(defaultExpression);
     $scope.state.selected = $scope.state.sheet.length - 1;
     $scope.safeSearch();
   };
 
-  $scope.setActiveCell = function(cell) {
+  $scope.setActiveCell = function (cell) {
     $scope.state.selected = cell;
   };
 
-  $scope.search = function() {
+  $scope.search = function () {
     $scope.state.save();
     $scope.running = true;
 
@@ -427,7 +428,7 @@ app.controller('timelion', function(
     const httpResult = $http
       .post('../api/timelion/run', {
         sheet: $scope.state.sheet,
-        time: _.extend(
+        time: _.assignIn(
           {
             from: timeRangeBounds.min,
             to: timeRangeBounds.max,
@@ -438,23 +439,23 @@ app.controller('timelion', function(
           }
         ),
       })
-      .then(resp => resp.data)
-      .catch(resp => {
+      .then((resp) => resp.data)
+      .catch((resp) => {
         throw resp.data;
       });
 
     httpResult
-      .then(function(resp) {
+      .then(function (resp) {
         $scope.stats = resp.stats;
         $scope.sheet = resp.sheet;
-        _.each(resp.sheet, function(cell) {
+        _.each(resp.sheet, function (cell) {
           if (cell.exception) {
             $scope.state.selected = cell.plot;
           }
         });
         $scope.running = false;
       })
-      .catch(function(resp) {
+      .catch(function (resp) {
         $scope.sheet = [];
         $scope.running = false;
 
@@ -475,7 +476,7 @@ app.controller('timelion', function(
     savedSheet.timelion_interval = $scope.state.interval;
     savedSheet.timelion_columns = $scope.state.columns;
     savedSheet.timelion_rows = $scope.state.rows;
-    savedSheet.save().then(function(id) {
+    savedSheet.save().then(function (id) {
       if (id) {
         toastNotifications.addSuccess({
           title: i18n.translate('timelion.saveSheet.successNotificationText', {
@@ -493,14 +494,14 @@ app.controller('timelion', function(
   }
 
   function saveExpression(title) {
-    savedVisualizations.get({ type: 'timelion' }).then(function(savedExpression) {
+    savedVisualizations.get({ type: 'timelion' }).then(function (savedExpression) {
       savedExpression.visState.params = {
         expression: $scope.state.sheet[$scope.state.selected],
         interval: $scope.state.interval,
       };
       savedExpression.title = title;
       savedExpression.visState.title = title;
-      savedExpression.save().then(function(id) {
+      savedExpression.save().then(function (id) {
         if (id) {
           toastNotifications.addSuccess(
             i18n.translate('timelion.saveExpression.successNotificationText', {
