@@ -20,14 +20,11 @@
 import 'angular';
 import '../chrome';
 import '../config';
-import '../es';
 import '../notify';
 import '../private';
 import '../promises';
-import '../modals';
 import '../state_management/app_state';
 import '../state_management/global_state';
-import '../style_compile';
 import '../url';
 import '../directives/watch_multi';
 import '../react_components';
