@@ -16,6 +16,11 @@
  * specific language governing permissions and limitations
  * under the License.
  */
+import { PromiseServiceCreator } from '../../../../plugins/kibana_legacy/public';
+export { createDefer } from './defer'; // @ts-ignore
 
-import './promises';
-export { createDefer } from './defer';
+import { uiModules } from '../modules';
+var module = uiModules.get('kibana'); // Provides a tiny subset of the excellent API from
+// bluebird, reimplemented using the $q service
+
+module.service('Promise', PromiseServiceCreator);
\ No newline at end of file
