@@ -16,15 +16,8 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-
 import { uiRegistry } from './_registry';
-
-export const RegistryFieldFormatEditorsProvider = uiRegistry({
+export var RegistryFieldFormatEditorsProvider = uiRegistry({
   name: 'fieldFormatEditors',
-  index: ['formatId'],
-  constructor: function() {
-    this.getEditor = function(formatId) {
-      return this.byFormatId[formatId];
-    };
-  },
-});
+  index: ['formatId']
+});
\ No newline at end of file
