@@ -17,7 +17,6 @@
  * under the License.
  */
 
-import { QueryString } from '../utils/query_string';
 import { StateProvider } from './state';
 import { uiModules } from '../modules';
 import { createLegacyClass } from '../utils/legacy_class';
@@ -35,13 +34,9 @@ export function GlobalStateProvider(Private) {
   // if the url param is missing, write it back
   GlobalState.prototype._persistAcrossApps = true;
 
-  GlobalState.prototype.removeFromUrl = function(url) {
-    return QueryString.replaceParamInUrl(url, this._urlParam, null);
-  };
-
   return new GlobalState();
 }
 
-module.service('globalState', function(Private) {
+module.service('globalState', function (Private) {
   return Private(GlobalStateProvider);
 });
