@@ -1,4 +1,4 @@
-'use strict';
+"use strict";
 
 /*
  * Licensed to Elasticsearch B.V. under one or more contributor
@@ -18,54 +18,48 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-
-var resolve = require('path').resolve;
-
-// this must happen before `require('babel-register')` and can't be changed
+var resolve = require('path').resolve; // this must happen before `require('@babel/register')` and can't be changed
 // once the module has been loaded
+
+
 if (!process.env.BABEL_CACHE_PATH) {
-  process.env.BABEL_CACHE_PATH = resolve(__dirname, '../../../optimize/.babelcache.json');
-}
+  process.env.BABEL_CACHE_PATH = resolve(__dirname, '../../../optimize/.babel_register_cache.json');
+} // paths that @babel/register should ignore
 
-// paths that babel-register should ignore
-var ignore = [/\/bower_components\//, /\/kbn-pm\/dist\//,
 
-// TODO: remove this and just transpile plugins at build time, but
+var ignore = [/[\/\\]bower_components[\/\\]/, /[\/\\]kbn-pm[\/\\]dist[\/\\]/, // TODO: remove this and just transpile plugins at build time, but
 // has tricky edge cases that will probably require better eslint
 // restrictions to make sure that code destined for the server/browser
 // follows respects the limitations of each environment.
 //
 // https://github.com/elastic/kibana/issues/14800#issuecomment-366130268
-
 // ignore paths matching `/node_modules/{a}/{b}`, unless `a`
 // is `x-pack` and `b` is not `node_modules`
-/\/node_modules\/(?!x-pack\/(?!node_modules)([^\/]+))([^\/]+\/[^\/]+)/,
+/[\/\\]node_modules[\/\\](?!x-pack[\/\\](?!node_modules)([^\/\\]+))([^\/\\]+[\/\\][^\/\\]+)/, // ignore paths matching `/canvas/canvas_plugin/`
+/[\/\\]canvas[\/\\]canvas_plugin[\/\\]/];
 
-// ignore paths matching `/canvas/canvas_plugin/`
-/\/canvas\/canvas_plugin\//];
-
-if ('true') {
+if ("true") {
   // when building the Kibana source we replace the statement
   // `global.__BUILT_WITH_BABEL__` with the value `true` so that
-  // when babel-register is required for the first time by users
+  // when @babel/register is required for the first time by users
   // it will exclude kibana's `src` directory.
   //
-  // We still need babel-register for plugins though, we've been
+  // We still need @babel/register for plugins though, we've been
   // building their server code at require-time since version 4.2
   // TODO: the plugin install process could transpile plugin server code...
   ignore.push(resolve(__dirname, '../../../src'));
 } else {
-  ignore.push(
-  // ignore any path in the packages, unless it is in the package's
+  ignore.push( // ignore any path in the packages, unless it is in the package's
   // root `src` directory, in any test or __tests__ directory, or it
   // ends with .test.js, .test.ts, or .test.tsx
-  /\/packages\/(eslint-|kbn-)[^\/]+\/(?!src\/.*|(.+\/)?(test|__tests__)\/.+|.+\.test\.(js|ts|tsx)$)(.+$)/);
-}
-
-// modifies all future calls to require() to automatically
+  /[\/\\]packages[\/\\](eslint-|kbn-)[^\/\\]+[\/\\](?!src[\/\\].*|(.+[\/\\])?(test|__tests__)[\/\\].+|.+\.test\.(js|ts|tsx)$)(.+$)/);
+} // modifies all future calls to require() to automatically
 // compile the required source with babel
-require('babel-register')({
+
+
+require('@babel/register')({
   ignore,
   babelrc: false,
-  presets: [require.resolve('@kbn/babel-preset/node_preset')]
+  presets: [require.resolve('@kbn/babel-preset/node_preset')],
+  extensions: ['.js', '.ts', '.tsx']
 });
\ No newline at end of file
