@@ -18,10 +18,6 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-require('symbol-observable');
-
-require('./root');
-
-require('./node_version_validator');
+require('./prebuilt_dev_only_entry');
 
 require('./babel_register');
\ No newline at end of file
