@@ -1,4 +1,4 @@
-'use strict';
+"use strict";
 
 /*
  * Licensed to Elasticsearch B.V. under one or more contributor
@@ -18,6 +18,6 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-
 require('script-loader!../node_modules/sinon/pkg/sinon.js');
+
 module.exports = window.sinon;
\ No newline at end of file
